##  Related Resources
  * SAP LeanIX website: [Application Rationalization - The Definitive Guide | LeanIX![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fwiki%2Fapm%2Fapplication-rationalization "https://www.leanix.net/en/wiki/apm/application-rationalization")
  * SAP Learning: [Mastering the Application Rationalization with SAP LeanIX![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Flearning-journeys%2Fmastering-the-application-rationalization-with-sap-leanix "https://learning.sap.com/learning-journeys/mastering-the-application-rationalization-with-sap-leanix")
  * SAP LeanIX Webinar: [How to Optimize IT Spend with LeanIX & Apptio](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Finfo.leanix.net%2Fleanix-webinar-optimizing-it-spend "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Finfo.leanix.net%2Fleanix-webinar-optimizing-it-spend")
  * White paper: [IT Cost Savings: A Guide to App Rationalization](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fapplication-rationalization-playbook "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fapplication-rationalization-playbook")
  * Blog: [Five Do's and Don'ts for IT Cost Optimization in 2022](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fblog%2Ffive-dos-and-donts-for-it-cost-optimization-in-2022 "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fblog%2Ffive-dos-and-donts-for-it-cost-optimization-in-2022")
  * Poster: [6 Ways to Save IT Costs](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2F6-ways-to-save-it-costs "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2F6-ways-to-save-it-costs")
  * Poster: [Application Rationalization Framework](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fapplication-rationalization-framework "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fapplication-rationalization-framework")
  * Customer story: [Innogy SE | How Innogy Uses LeanIX and Apptio to Enable Cost Transparency](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcustomers%2Fsuccess-stories%2Finnogy "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fcustomers%2Fsuccess-stories%2Finnogy")


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
